/**********************************************************
***********************************************************
*				European Southern Observatory
*		     VLTI MIDI Data Reduction Software
*
* Module name:	complex.h
* Description:	
*
*
* History:		
* 03-Feb-03		(jmeisner) Created
* 03-Mar-03		(csabet) Added title, directives and included in the MIDI pipeline
***********************************************************
**********************************************************/
#ifndef _COMPLEX_H_MIDI
#define _COMPLEX_H_MIDI

/**********************************************************
*	Include files
**********************************************************/

/**********************************************************
*	Constant definitions
**********************************************************/

/**********************************************************
*	Global Variables 
**********************************************************/

/**********************************************************
*	Type definitions 
**********************************************************/
struct Complex
{
	float	r, i;
};

extern struct Complex	Czero;	//	CONSTANT for use by apps. DO NOT CHANGE IT, EVER!!!

/**********************************************************
*	Macro Definitions
**********************************************************/
#define MAKEC(real, imag, result)  {result.r = real; result.i = imag;}
#define SETTOCONJ(dest, source) {dest.r = source.r;  dest.i = -source.i;}

/**********************************************************
*	Function Prototypes
**********************************************************/
struct Complex Addc(struct Complex, struct Complex);
struct Complex Subtractc(struct Complex, struct Complex);
struct Complex Multiplyc(struct Complex z1, struct Complex z2);
struct Complex Dividec(struct Complex z1, struct Complex z2);

//	Same as above but use pointers:
void AddCptr(struct Complex *result, struct Complex *z1, struct Complex *z2);
void SubtractCptr(struct Complex *result, struct Complex *z1, struct Complex *z2);
void MultiplyCptr(struct Complex *result, struct Complex *z1, struct Complex *z2);
void MultiplyConjPtr(struct Complex *result, struct Complex *z1, struct Complex *z2);

struct Complex Scalec(struct Complex z, float scale);
struct Complex Unitc(struct Complex z);
float  Cmag(struct Complex);
float Cmag2(struct Complex);
void GetEtoJtimes(float, struct Complex *);
void GetScaledEtoJtimes(float Angle, struct Complex *Result, float scale);
void RotateBy(float, struct Complex *);

//	New Nov 9, 1999:
//	Returns a positive real part, if 0 then returns neg imag part.
struct Complex Csqrt(struct Complex);
void GetExpc(struct Complex *Result, struct Complex z);
struct Complex jtimes(struct Complex z);

// 	Richard added on these
void printC(struct Complex z);
float Arg(struct Complex z);

/*********************************************************/
#endif
/*********************************************************/
